@@ -1,4 +1,4 @@
-# $Id: KusumiKoharu.pm 20 2005-05-01 14:24:19Z kentaro $
+# $Id: KusumiKoharu.pm 8 2005-09-04 02:44:38Z kentaro $
 
 package Acme::MorningMusume::KusumiKoharu;
 
@@ -7,7 +7,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub info {
 	return (
@@ -15,11 +15,11 @@ sub info {
 		family_name_ja => '久住',
 		first_name_en  => 'Koharu',
 		family_name_en => 'Kusumi',
-		nick           => [],
+		nick           => [qw(こは くすみん くすこ)],
 		birthday       => Date::Simple->new('1992-07-15'),
-		blood_type     => 'unknown',
+		blood_type     => 'A',
 		hometown       => '新潟県',
-		emoticon       => [],
+		emoticon       => ['从б_бﾘ', 'ﾘo´ｩ｀ﾘ'],
 		class          => 7,
 		graduate_date  => undef,
 	);
